@@ -30,9 +30,36 @@ def extract_script_body(soup: BeautifulSoup) -> str:
 
 
 def get_ac_url(url: str, lang: str) -> str:
-    d = {"cpp": 1, "pypy3": 16, "python3": 2, "ts": 11}
+    language = {
+        "c": 5,
+        "cpp": 1,
+        "cs": 7,
+        "csharp": 7,
+        "go": 9,
+        "golang": 9,
+        "haskell": 15,
+        "hs": 15,
+        "java": 6,
+        "javascript": 8,
+        "js": 8,
+        "php": 17,
+        "py": 2,
+        "pypy": 16,
+        "pypy3": 16,
+        "python": 2,
+        "python3": 2,
+        "rb": 3,
+        "rs": 13,
+        "ruby": 3,
+        "ruby3": 3,
+        "rust": 13,
+        "ts": 11,
+        "typescript": 11,
+    }.get(lang)
+    if language is None:
+        return f"{url}/submissions?id={get_task_id(url)}&status=AC&page=0"
     return (
-        f"{url}/submissions?id={get_task_id(url)}&language={d[lang]}&status=AC&page=0"
+        f"{url}/submissions?id={get_task_id(url)}&language={language}&status=AC&page=0"
     )
 
 
