@@ -30,8 +30,36 @@ def compose_get_samples(soup: BeautifulSoup) -> Callable[[IorO], list[str]]:
 
 
 def get_ac_url(url: str, lang: str) -> str:
-    d = {"cpp": "C%2B%2B", "pypy3": "Python3", "python3": "Python3", "ts": "TypeScript"}
-    return f"{BASE_URL}{get_contest_name(url)}/submissions?f.Task={get_task_name(url)}&f.LanguageName={d[lang]}&f.Status=AC&f.User="
+    language_name = {
+        "bash": "Bash",
+        "c": "C",
+        "cpp": "C%2B%2B",
+        "cs": "C%23",
+        "csharp": "C%23",
+        "go": "Go",
+        "golang": "Go",
+        "haskell": "Haskell",
+        "hs": "Haskell",
+        "java": "Java",
+        "javascript": "JavaScript",
+        "js": "JavaScript",
+        "php": "PHP",
+        "py": "Python3",
+        "pypy": "Python3",
+        "pypy2": "Python2",
+        "pypy3": "Python3",
+        "python": "Python3",
+        "python2": "Python2",
+        "python3": "Python3",
+        "rb": "Ruby",
+        "rs": "Rust",
+        "ruby": "Ruby",
+        "rust": "Rust",
+        "ts": "TypeScript",
+        "typescript": "TypeScript",
+        "zsh": "Zsh",
+    }.get(lang, "")
+    return f"{BASE_URL}{get_contest_name(url)}/submissions?f.Task={get_task_name(url)}&f.LanguageName={language_name}&f.Status=AC&f.User="
 
 
 def get_contest_name(url: str) -> str:
