@@ -3,22 +3,27 @@ from __future__ import annotations
 import platform
 from pathlib import Path
 
-from acac import __version__, core
-from acac.config import load_config
+from acac import __version__, config, core
 from acac.util import console, includes
 
 HELP_MESSAGE = """\
 競プロ便利ツール。
 
 [bold]Usage:[/bold]
-  acac
+  acac <url> \\[options]
+  acac init                              Create configuration file "acac.toml".
 
 [bold]Options:[/bold]
-  [blue]-j[/blue]              judge.
+  [blue]-c, --create[/blue]                           Create environment mode. (default)
+  [blue]-j, --judge[/blue]                            Judge mode.
+  [blue]-m, --manual[/blue]                           URL にアクセスせず、HTML ファイルを手動で配置してテストケースを作成するモード。
+
+  [blue]-l, --lang,   lang=LANG_NAME[/blue]           言語を指定する。
+  [blue]-s, --source, source=SOURCE_FILE_NAME[/blue]  ソースファイル名を指定する。
 
 [bold]Global options:[/bold]
-  [blue]-h, --help[/blue]      Show this help message and exit.
-  [blue]-V, --version[/blue]   Show program's version number and exit.
+  [blue]-h, --help[/blue]                             Show this help message and exit.
+  [blue]-V, --version[/blue]                          Show program's version number and exit.
 
 See https://github.com/seijinrosen/acac for more information.\
 """
@@ -44,6 +49,7 @@ def main(args: list[str]) -> None:
         return
 
     if args[0] == "init":
+        config.init()
         return
 
-    core.main(args, load_config())
+    core.main(args, config.load())
