@@ -12,14 +12,21 @@ from rich.table import Table
 
 from acac import algo_method, atcoder
 from acac.config import Config
-from acac.share import Folder, ProblemType
-from acac.util import UTF_8, confirm_yN, console, run_with_log
+from acac.share import Folder, ProblemType, expand_command
+from acac.util import (
+    UTF_8,
+    confirm_yN,
+    console,
+    copy2clip_with_log,
+    replaced,
+    run_with_log,
+)
 
 
 class IOSample(BaseModel):
-    name: str
-    in_: str
-    out: str
+    in_file: Path
+    in_text: str
+    out_text: str
 
 
 class Result(BaseModel):
@@ -33,68 +40,73 @@ class Result(BaseModel):
 
 
 def main(
-    url: str, folder: Folder, problem_type: ProblemType, lang: str, config: Config
+    url: str,
+    folder: Folder,
+    problem_type: ProblemType,
+    lang_name: str,
+    config: Config,
+    replace_map: dict[str, str],
 ) -> None:
-    lang_command = get_lang_command(config.lang[lang].command)
-    run_with_log([lang_command, "--version"], check=True)
-    io_samples = load_io_samples(folder.in_, folder.out)
+    lang_setting = config.language.settings[lang_name]
 
-    if lang == "cpp":
-        a_out = folder.path / "a.out"
-        run_with_log([lang_command, folder.exec_file, "-o", a_out], check=True)
-        results = get_results([a_out], io_samples)
-    else:
-        results = get_results([lang_command, folder.exec_file], io_samples)
+    for cmd in lang_setting.commands.pre_execute:
+        run_with_log(expand_command(cmd, replace_map), check=True)
+
+    results = get_results(
+        expand_command(lang_setting.commands.execute, replace_map),
+        load_io_samples(folder.in_, folder.out),
+    )
+
+    for cmd in lang_setting.commands.post_execute:
+        run_with_log(expand_command(cmd, replace_map), check=True)
 
     console.print(create_table(results))
 
     if all(r.is_accepted for r in results):
         console.print("All Completed! AC!!!:thumbs_up:", style="green")
-        if config.judge.clipboard_message:
-            clipboard_message = config.judge.clipboard_message.replace(
-                "${url}", url
-            ).replace("${lang}", lang)
-            pyperclip.copy(clipboard_message)  # type: ignore
-            console.print("以下の文字列がクリップボードにコピーされました。")
-            console.print(clipboard_message)
+
+        if config.judge.copy_source_code_when_ac:
+            source_code = folder.source_file.read_text(encoding=UTF_8)
+            pyperclip.copy(source_code)  # type: ignore
+            console.print("[bold]Copied source code to clipboard:", folder.source_file)
+
         if problem_type in {"algo_method", "atcoder"} and confirm_yN("他の人の提出を確認しますか？"):
-            webbrowser.open(get_ac_url(problem_type, url, lang))
+            ac_url = get_ac_url(problem_type, url, lang_name)
+            webbrowser.open(ac_url)
+            console.print("[bold]Opened:", ac_url)
+
+        if config.judge.clipboard_message:
+            copy2clip_with_log(replaced(config.judge.clipboard_message, replace_map))
     else:
         console.print("WA...:", end=" ", style="red")
         console.print(*[r.name for r in results if not r.is_accepted])
 
 
-def get_lang_command(command: str) -> str | Path:
-    if command.startswith("~"):
-        return Path(command).expanduser()
-    return command
-
-
 def load_io_samples(i_dir: Path, o_dir: Path) -> list[IOSample]:
     return [
         IOSample(
-            name=i_file.stem,
-            in_=i_file.read_text(encoding=UTF_8),
-            out=o_file.read_text(encoding=UTF_8),
+            in_file=i_file,
+            in_text=i_file.read_text(encoding=UTF_8),
+            out_text=o_file.read_text(encoding=UTF_8),
         )
         for i_file, o_file in zip(sorted(i_dir.iterdir()), sorted(o_dir.iterdir()))
     ]
 
 
-def get_results(cmd_args: list[str | Path], io_samples: list[IOSample]) -> list[Result]:
+def get_results(execute_command: list[str], io_samples: list[IOSample]) -> list[Result]:
     def get_result(io_sample: IOSample) -> Result:
         start = time.time()
-        console.print(f"[bold]Running {io_sample.name}:", *cmd_args)
+        console.print("[bold]Running:", *execute_command, "<", io_sample.in_file)
         cp = subprocess.run(
-            cmd_args, capture_output=True, input=io_sample.in_, text=True
+            execute_command, capture_output=True, input=io_sample.in_text, text=True
         )
         return Result(
-            name=io_sample.name,
-            input=io_sample.in_,
-            expected=io_sample.out,
-            actual=cp.stdout,
+            name=io_sample.in_file.name,
+            input=io_sample.in_text.rstrip(),
+            expected=io_sample.out_text.rstrip(),
+            actual=cp.stdout.rstrip(),
             error=cp.stderr,
-            is_accepted=io_sample.out == cp.stdout,
+            is_accepted=io_sample.out_text.strip() == cp.stdout.strip(),
             execution_ms=int((time.time() - start) * 1000),
         )
 
